@@ -239,7 +239,10 @@ void do_child(int *fds)
 		MemoryContextSwitchTo(ProcessLoopContext);
 
 		if (accepted)
+		{
+			accepted = 0;
 			connection_count_down();
+		}
         
         backend_cleanup(&child_frontend, backend, frontend_invalid);
 
@@ -632,6 +635,10 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 						(errmsg("reading startup packet"),
 							 errdetail("application_name: %s", p)));
 				}
+				else
+				{
+					p += (strlen(p) + 1);
+				}
 
 				p += (strlen(p) + 1);
 			}
