@@ -328,7 +328,12 @@ void pool_connection_pool_timer(POOL_CONNECTION_POOL *backend)
 		(errmsg("setting backend connection close timer"),
 			 errdetail("close time %ld", time(NULL))));
 
-	MASTER_CONNECTION(backend)->closetime = time(NULL);		/* set connection close time */
+	/* Set connection close time */
+	for (i = 0; i < NUM_BACKENDS; i++)
+	{
+		if (CONNECTION_SLOT(backend, i))
+			CONNECTION_SLOT(backend, i)->closetime = time(NULL);
+	}
 
 	if (pool_config->connection_life_time == 0)
 		return;
